/**
 * Copyright (c) 2000-2009 Liferay, Inc. All rights reserved.
 *
 *
 *
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.liferay.portlet.xslcontent.util;

import com.liferay.portal.kernel.util.ByteArrayMaker;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.HttpUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.util.PropsUtil;

import java.io.IOException;
import java.io.StringReader;

import java.net.URL;

import javax.xml.XMLConstants;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

/**
 * <a href="XSLContentUtil.java.html"><b><i>View Source</i></b></a>
 *
 * @author Brian Wing Shun Chan
 *
 */
public class XSLContentUtil {

	public static String DEFAULT_XML_URL =
		"@portal_url@/html/portlet/xsl_content/example.xml";

	public static String DEFAULT_XSL_URL =
		"@portal_url@/html/portlet/xsl_content/example.xsl";

	public static String transform(URL xmlURL, URL xslURL)
		throws IOException, TransformerException {

		String xml = HttpUtil.URLtoString(xmlURL);
		String xsl = HttpUtil.URLtoString(xslURL);

		StreamSource xmlSource = new StreamSource(new StringReader(xml));
		StreamSource xslSource = new StreamSource(new StringReader(xsl));

		TransformerFactory transformerFactory =
			TransformerFactory.newInstance();

		Transformer transformer =
			transformerFactory.newTransformer(xslSource);

		String XSL_CONTENT_SECURE_PROCESSING_ENABLED = null;

		try {
			XSL_CONTENT_SECURE_PROCESSING_ENABLED =
				PropsUtil.get("xsl.content.secure.processing.enabled");
		}
		catch (Exception e) {
		}

		boolean secureProcessingEnabled = true;

		if (Validator.isNotNull(XSL_CONTENT_SECURE_PROCESSING_ENABLED)) {
			secureProcessingEnabled =
				GetterUtil.getBoolean(XSL_CONTENT_SECURE_PROCESSING_ENABLED);
		}

		transformerFactory.setFeature(
			XMLConstants.FEATURE_SECURE_PROCESSING, secureProcessingEnabled);

		ByteArrayMaker bam = new ByteArrayMaker();

		transformer.transform(xmlSource, new StreamResult(bam));

		return bam.toString();
	}

}